@@ -1,21 +1,13 @@
-from typing import Optional
-import os
-import sys
-sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
-from info import *
-from typing import Iterable
-from info import SysOutputInfo
-from info import BucketPerformance
-from info import Performance
-from info import Table
+from typing import Optional, Iterable
+from explainaboard.info import SysOutputInfo, BucketPerformance, Performance, Table
 from explainaboard.utils import analysis
 from explainaboard.utils.analysis import *
 from explainaboard.utils.eval_bucket import *
-from metric import Accuracy
-from metric import F1score
-
-"""TODO
-"""
+from explainaboard.metric import Accuracy
+from explainaboard.metric import F1score
+from tqdm import tqdm
+from explainaboard.utils.feature_funcs import *
+from explainaboard.utils.spacy_loader import spacy_loader
 
 
 class TCExplainaboardBuilder:
@@ -64,9 +56,19 @@ class TCExplainaboardBuilder:
     def _get_token_number(self, existing_feature: dict):
         return len(existing_feature["text"])
 
+    def _get_entity_number(self, existing_feature: dict):
+        return len(spacy_loader.get_model("en_core_web_sm")(existing_feature["text"]).ents)
+    
     def _get_label(self, existing_feature: dict):
         return existing_feature["true_label"]
 
+    def _get_basic_words(self, existing_feature: dict):
+        return get_basic_words(existing_feature["text"])
+
+    def _get_lexical_richness(self, existing_feature: dict):
+        return get_lexical_richness(existing_feature["text"])
+
+
     def _complete_feature(self):
         """
         This function is used to calculate features used for bucekting, such as sentence_length
@@ -74,9 +76,9 @@ class TCExplainaboardBuilder:
         :return:
         """
         # Get names of bucketing features
-        print(f"self._info.features.get_bucket_features()\n {self._info.features.get_bucket_features()}")
+        #print(f"self._info.features.get_bucket_features()\n {self._info.features.get_bucket_features()}")
         bucket_features = self._info.features.get_bucket_features()
-        for _id, dict_sysout in enumerate(self._system_output):
+        for _id, dict_sysout in tqdm(enumerate(self._system_output), desc="featurizing"):
             # Get values of bucketing features
             for bucket_feature in bucket_features:
                 feature_value = eval(TCExplainaboardBuilder.get_bucket_feature_value(bucket_feature))(dict_sysout)
@@ -109,15 +111,16 @@ class TCExplainaboardBuilder:
             confidence_score_up = overall_value_json["confidence_score_up"]
             overall_performance = Performance(
                                                    metric_name=metric_name,
-                                                   value=format(overall_value, '.4g'),
-                                                   confidence_score_low=format(confidence_score_low, '.4g'),
-                                                   confidence_score_up=format(confidence_score_up, '.4g')
+                                                   value=float(format(overall_value, '.4g')),
+                                                   confidence_score_low=float(format(confidence_score_low, '.4g')),
+                                                   confidence_score_up=float(format(confidence_score_up, '.4g'))
             )
 
             if self._info.results.overall == None:
-                self._info.results.overall = [overall_performance]
+                self._info.results.overall = {}
+                self._info.results.overall[metric_name] = overall_performance
             else:
-                self._info.results.overall.append(overall_performance)
+                self._info.results.overall[metric_name] = overall_performance
 
     def _bucketing_samples(self, sysout_iterator):
 
@@ -136,19 +139,19 @@ class TCExplainaboardBuilder:
                     feature_to_sample_address_to_value[feature_name][sample_address] = dict_sysout[feature_name]
 
         # Bucketing
-        for feature_name in self._info.features.get_bucket_features():
+        for feature_name in tqdm(self._info.features.get_bucket_features(), desc="bucketing"):
 
-            print(f"Feature Name: {feature_name}\n"
-                  f"Bucket Hyper:\n function_name: {self._info.features[feature_name].bucket_info._method} \n"
-                  f"bucket_number: {self._info.features[feature_name].bucket_info._number}\n"
-                  f"bucket_setting: {self._info.features[feature_name].bucket_info._setting}\n")
+            # print(f"Feature Name: {feature_name}\n"
+            #       f"Bucket Hyper:\n function_name: {self._info.features[feature_name].bucket_info._method} \n"
+            #       f"bucket_number: {self._info.features[feature_name].bucket_info._number}\n"
+            #       f"bucket_setting: {self._info.features[feature_name].bucket_info._setting}\n")
 
             self._samples_over_bucket[feature_name] = eval(self._info.features[feature_name].bucket_info._method)(
                                 dict_obj = feature_to_sample_address_to_value[feature_name],
                                 bucket_number = self._info.features[feature_name].bucket_info._number,
                                 bucket_setting = self._info.features[feature_name].bucket_info._setting)
 
-            print(f"self._samples_over_bucket.keys():\n{self._samples_over_bucket.keys()}")
+            # print(f"self._samples_over_bucket.keys():\n{self._samples_over_bucket.keys()}")
 
             # evaluating bucket: get bucket performance
             self._performances_over_bucket[feature_name] = self.get_bucket_performance(feature_name)
@@ -202,11 +205,11 @@ class TCExplainaboardBuilder:
                 confidence_score_low = bucket_value_json["confidence_score_low"]
                 confidence_score_up = bucket_value_json["confidence_score_up"]
 
-                print(f"name:\t {one_metric._name} \n"
-                      f"value:\t {bucket_value}\n"
-                      f"confidence low\t {confidence_score_low}\n"
-                      f"confidence up \t {confidence_score_up}\n"
-                      f"---------------------------------")
+                # print(f"name:\t {one_metric._name} \n"
+                #       f"value:\t {bucket_value}\n"
+                #       f"confidence low\t {confidence_score_low}\n"
+                #       f"confidence up \t {confidence_score_up}\n"
+                #       f"---------------------------------")
 
                 bucket_performance = BucketPerformance(bucket_name=bucket_interval,
                                   metric_name = metric_name,
