@@ -244,6 +244,7 @@ class ClassLabel:
 
     num_classes: int = None
     names: List[str] = None
+    description: str = None
     names_file: Optional[str] = None
     id: Optional[str] = None
     is_bucket: bool = False
@@ -436,6 +437,7 @@ class Value:
     """
 
     dtype: str # must be initialized when created
+    description: str = None
     is_bucket: bool = False # don't need to be initialized
     is_pre_computed: bool = False
     bucket_info: BucketInfo = None
@@ -622,17 +624,17 @@ class Features(dict):
 
             # curr_feature = self[feature_name].copy()
             # while "feature" in self[feature_name].__dict__.keys():
-        print("--++----- leaf features ---++------")
+        # print("--++----- leaf features ---++------")
         for feature_name, feature_info in dict_res.items():
-            print(k,v)
+            # print(k,v)
             if "is_pre_computed" not in feature_info.__dict__.keys():
                 continue
             if feature_info.is_pre_computed:
                 pre_computed_features.append(feature_name)
 
-        print("--++----- pre_computed features ---++------")
-        for feature_name in pre_computed_features:
-            print(feature_name)
+        # print("--++----- pre_computed features ---++------")
+        # for feature_name in pre_computed_features:
+        #     print(feature_name)
 
         return pre_computed_features
 
